@@ -49,6 +49,7 @@ class Post():
                 self.clean_content = self.clean_content[9:]
             self.town = 'Damascus'
 
+        self.clean_content.replace('.<br/>', '. ')
         self.sentences = self.clean_content.split('. ')
         self.contents = []
 
@@ -65,6 +66,8 @@ class Post():
                 'take control',
                 'ambush',
                 'raid',
+                'suicide',
+                'fighter-jet',
             ]
 
         for sentence in self.sentences:
